# [1.5.5](https://github.com/seriaati/seria-library/compare/v1.5.4..v1.5.5) - 2025-02-27

## Bug Fixes

- **(deps)** update dependency aiohttp to v3.10.0 - ([b3e5b37](https://github.com/seriaati/seria-library/commit/b3e5b374e86f257fbd7db60f4aacc053e30b45b1))
- **(deps)** update dependency aiohttp to v3.10.1 - ([602efb9](https://github.com/seriaati/seria-library/commit/602efb9706a0d2a8a90fa8e83053f5f70d57eb17))
- **(deps)** update dependency pyyaml to v6.0.2 - ([7cbbf36](https://github.com/seriaati/seria-library/commit/7cbbf3606f34114fa90e06b0dafbfca8e4a16454))
- **(deps)** update dependency aiohttp to v3.10.2 - ([a593339](https://github.com/seriaati/seria-library/commit/a593339c518861f7365eaa18531454a9968f761f))
- **(deps)** update dependency orjson to v3.10.7 - ([9d83f97](https://github.com/seriaati/seria-library/commit/9d83f97087070e13eb5cb3ad26865ee8c0bd48d0))
- **(deps)** update dependency aiohttp to v3.10.3 - ([86e2936](https://github.com/seriaati/seria-library/commit/86e293684c326056cf2598e87d48572023ee3055))
- **(deps)** update dependency tortoise-orm to v0.21.6 - ([cdaacd6](https://github.com/seriaati/seria-library/commit/cdaacd644ba4b002053e29070873b1c37a0f942c))
- **(deps)** update dependency aiohttp to v3.10.4 - ([f36156c](https://github.com/seriaati/seria-library/commit/f36156c5ff716df18447dd885d9ce38f93e53161))
- **(deps)** update dependency aiohttp to v3.10.5 - ([6139f33](https://github.com/seriaati/seria-library/commit/6139f3310ae2c5080539ce53f34f5278a5006225))
- **(deps)** update dependency aiohttp to v3.10.6 - ([0a4d145](https://github.com/seriaati/seria-library/commit/0a4d1452e6d1a6ef6a9c085ab86e52f3fc299a9b))
- **(deps)** update dependency aiohttp to v3.10.7 - ([0930e5a](https://github.com/seriaati/seria-library/commit/0930e5adfce198c5fb2acec959ebf8cdf100c1e6))
- **(deps)** update dependency aiohttp to v3.10.8 - ([bd24fa3](https://github.com/seriaati/seria-library/commit/bd24fa395d1703e1270f8569d2e40a6e51385b86))
- **(deps)** update dependency aiohttp to v3.10.9 - ([7855870](https://github.com/seriaati/seria-library/commit/7855870e27a30d518c5c044054c3973010115bd8))
- **(deps)** update dependency aiohttp to v3.10.10 - ([dd09625](https://github.com/seriaati/seria-library/commit/dd09625cf33946698387fc2c3474540f8053fd01))
- **(deps)** update dependency tortoise-orm to v0.21.7 - ([71accde](https://github.com/seriaati/seria-library/commit/71accde797cac9936b6c2580e2eecb1157edc2e3))
- **(deps)** update dependency orjson to v3.10.9 - ([24c24f1](https://github.com/seriaati/seria-library/commit/24c24f1366dd0403028987fa3231f5d35bcd06ff))
- **(deps)** update dependency orjson to v3.10.10 - ([a125581](https://github.com/seriaati/seria-library/commit/a12558121b76accef62912f9614dc8c74e85e6fa))
- **(deps)** update dependency orjson to v3.10.11 - ([c6333ae](https://github.com/seriaati/seria-library/commit/c6333aeb40af8b30150f854349291554daad560a))
- **(deps)** update dependency aiohttp to v3.11.0 ([#76](https://github.com/seriaati/seria-library/issues/76)) - ([4cd20a1](https://github.com/seriaati/seria-library/commit/4cd20a1583dff26d93c01bb80b132cb7c0424d3b))
- **(deps)** update dependency aiohttp to v3.11.1 ([#77](https://github.com/seriaati/seria-library/issues/77)) - ([7f17644](https://github.com/seriaati/seria-library/commit/7f17644609959f1de7df19b056cde194155709a2))
- **(deps)** update dependency aiohttp to v3.11.2 ([#78](https://github.com/seriaati/seria-library/issues/78)) - ([4bbfd88](https://github.com/seriaati/seria-library/commit/4bbfd88760ba81460032fd8ba119fc7149774770))
- **(deps)** update dependency aiohttp to v3.11.3 ([#80](https://github.com/seriaati/seria-library/issues/80)) - ([8d406a1](https://github.com/seriaati/seria-library/commit/8d406a123d57c2f26561c54cb03939b1d75f5309))
- **(deps)** update dependency aiohttp to v3.11.4 ([#81](https://github.com/seriaati/seria-library/issues/81)) - ([1babb94](https://github.com/seriaati/seria-library/commit/1babb94bedfd9fa0e326e1512af834dac9bafa13))
- **(deps)** update dependency aiohttp to v3.11.5 ([#82](https://github.com/seriaati/seria-library/issues/82)) - ([3a53092](https://github.com/seriaati/seria-library/commit/3a53092836e5fe216d8f27b619da15af565e78c0))
- **(deps)** update dependency aiohttp to v3.11.6 ([#83](https://github.com/seriaati/seria-library/issues/83)) - ([fbd5792](https://github.com/seriaati/seria-library/commit/fbd57927657c6be549fb4a48b50d3efcaa57929f))
- **(deps)** update dependency tortoise-orm to ^0.22.0 ([#84](https://github.com/seriaati/seria-library/issues/84)) - ([dfcdc9d](https://github.com/seriaati/seria-library/commit/dfcdc9db914003a39a3c5bed768256255013b84c))
- **(deps)** update dependency aiohttp to v3.11.7 ([#85](https://github.com/seriaati/seria-library/issues/85)) - ([d5c6599](https://github.com/seriaati/seria-library/commit/d5c659999e2f3f8207f457a235c244d2adb465ce))
- **(deps)** update dependency orjson to v3.10.12 ([#87](https://github.com/seriaati/seria-library/issues/87)) - ([388dc1e](https://github.com/seriaati/seria-library/commit/388dc1e85af579e68dc5606949a1f9de2c3b9ea0))
- **(deps)** update dependency tortoise-orm to v0.22.1 ([#88](https://github.com/seriaati/seria-library/issues/88)) - ([48e313c](https://github.com/seriaati/seria-library/commit/48e313c6985b0e2f644b969924d88930107c9045))
- **(deps)** update dependency aiohttp to v3.11.8 ([#89](https://github.com/seriaati/seria-library/issues/89)) - ([9dc7287](https://github.com/seriaati/seria-library/commit/9dc7287eec11bfc67323c5ca2fe179b9867235b5))
- **(deps)** update dependency aiohttp to v3.11.9 ([#91](https://github.com/seriaati/seria-library/issues/91)) - ([0fc3c8e](https://github.com/seriaati/seria-library/commit/0fc3c8ebfe2a26e77fe0dfa69db005c6ba0b47de))
- **(deps)** update dependency aiohttp to v3.11.10 ([#93](https://github.com/seriaati/seria-library/issues/93)) - ([e8e60c7](https://github.com/seriaati/seria-library/commit/e8e60c755a076e0ba5972852163dd98f5dd8ff11))
- **(deps)** update dependency tortoise-orm to v0.22.2 ([#94](https://github.com/seriaati/seria-library/issues/94)) - ([8519238](https://github.com/seriaati/seria-library/commit/8519238c92e7d7e922e31be5f701972cc6c2df80))
- **(deps)** update dependency aiohttp to v3.11.11 ([#96](https://github.com/seriaati/seria-library/issues/96)) - ([0944f3b](https://github.com/seriaati/seria-library/commit/0944f3b25644017f30903068d442807c35833727))
- **(deps)** update dependency tortoise-orm to ^0.23.0 ([#98](https://github.com/seriaati/seria-library/issues/98)) - ([8890323](https://github.com/seriaati/seria-library/commit/8890323bdb453151a31d8d5aebfd166a334508bb))
- **(deps)** update dependency orjson to v3.10.13 ([#99](https://github.com/seriaati/seria-library/issues/99)) - ([d800430](https://github.com/seriaati/seria-library/commit/d800430c3ec790655331a88833611130ea42dcdb))
- **(deps)** update dependency orjson to v3.10.14 ([#102](https://github.com/seriaati/seria-library/issues/102)) - ([9683008](https://github.com/seriaati/seria-library/commit/9683008ee7a7d6485736aada8e596207453d0c0f))
- **(deps)** update dependency orjson to v3.10.15 ([#106](https://github.com/seriaati/seria-library/issues/106)) - ([c97f877](https://github.com/seriaati/seria-library/commit/c97f8774365857e9d01fc6459e2dc1731d4b4ac3))
- **(deps)** update dependency tortoise-orm to ^0.24.0 ([#107](https://github.com/seriaati/seria-library/issues/107)) - ([f2f8c61](https://github.com/seriaati/seria-library/commit/f2f8c6159fc2214e69a5e60d663743234da24b40))
- **(deps)** update dependency aiohttp to v3.11.12 ([#110](https://github.com/seriaati/seria-library/issues/110)) - ([80ecdff](https://github.com/seriaati/seria-library/commit/80ecdffec84cb3a1601240eba9b19c3dfa402941))
- **(deps)** update dependency discord-py to v2.5.0 ([#113](https://github.com/seriaati/seria-library/issues/113)) - ([3d6c9fc](https://github.com/seriaati/seria-library/commit/3d6c9fc5bf58ac797b22f2911df9fc8628716e26))
- **(deps)** update dependency tortoise-orm to v0.24.1 ([#115](https://github.com/seriaati/seria-library/issues/115)) - ([be25df2](https://github.com/seriaati/seria-library/commit/be25df2d9fc3ee6b5c751cc5b6170e30108d7561))
- **(deps)** update dependency aiohttp to v3.11.13 ([#116](https://github.com/seriaati/seria-library/issues/116)) - ([3d64afe](https://github.com/seriaati/seria-library/commit/3d64afe16b2404c9aaa19f2faa2f7a552e365f33))

## Continuous Integrations

- Update ruff lint workflow config - ([81eae98](https://github.com/seriaati/seria-library/commit/81eae9867f1accc41cc5be0390765414e5b8aee9))

## Features

- Support passing pathlib.Path into read file funcs - ([3fb93ed](https://github.com/seriaati/seria-library/commit/3fb93edc1ca071ab1fd1b7bbb6766c1050bafb25))

## Miscellaneous Chores

- **(deps)** update dependency ruff to v0.5.6 - ([642affe](https://github.com/seriaati/seria-library/commit/642affe2e027fabef3d4e5c1191a35d4d20eaef3))
- **(deps)** update dependency ruff to v0.5.7 - ([5197303](https://github.com/seriaati/seria-library/commit/519730378b35c7c4fdf42f9da8c1afabb10a38d0))
- **(deps)** update dependency ruff to ^0.6.0 - ([503915b](https://github.com/seriaati/seria-library/commit/503915bc25d16e1383224f14674c8e1cee899ea6))
- **(deps)** update dependency uvloop to ^0.20.0 - ([9ec93bc](https://github.com/seriaati/seria-library/commit/9ec93bc7e6abc2e7d74c9e8f590261159e657d25))
- **(deps)** update dependency ruff to v0.6.1 - ([ffc0f4d](https://github.com/seriaati/seria-library/commit/ffc0f4d23e056a922e90c091902e5ec87161551d))
- **(deps)** update dependency ruff to v0.6.2 - ([59cb84a](https://github.com/seriaati/seria-library/commit/59cb84a39666df326593a82881dbd177f90ca852))
- **(deps)** update dependency ruff to v0.6.3 - ([e9f5fe2](https://github.com/seriaati/seria-library/commit/e9f5fe210268854541eeb9e99f83ba257fe3a949))
- **(deps)** update dependency ruff to v0.6.4 - ([d34fd16](https://github.com/seriaati/seria-library/commit/d34fd162394a6cdfd56be59de97beb98cc68e911))
- **(deps)** update dependency ruff to v0.6.5 - ([3120f3c](https://github.com/seriaati/seria-library/commit/3120f3cd9cb778f493212f813f9316b1171e7a08))
- **(deps)** update dependency ruff to v0.6.6 - ([3f08f46](https://github.com/seriaati/seria-library/commit/3f08f461dbfd12f312624024f741b890976da55c))
- **(deps)** update dependency ruff to v0.6.7 - ([dfe857b](https://github.com/seriaati/seria-library/commit/dfe857bed3d591f41a33b60539f5364e25efbb82))
- **(deps)** update dependency ruff to v0.6.8 - ([138c04c](https://github.com/seriaati/seria-library/commit/138c04cdc9edcf26ff9a42eb80660a69561d60d6))
- **(deps)** update dependency ruff to v0.6.9 - ([9e56441](https://github.com/seriaati/seria-library/commit/9e56441e62d6deac9039f60e268da4cb5ef40816))
- **(deps)** update dependency uvloop to ^0.21.0 - ([bb7c456](https://github.com/seriaati/seria-library/commit/bb7c456312ec11945f3bb19e1c10092ca346a4d6))
- **(deps)** update dependency ruff to ^0.7.0 - ([490a60a](https://github.com/seriaati/seria-library/commit/490a60a1e67ede9a16b7bbc04cc8787c2c23cbae))
- **(deps)** update dependency ruff to v0.7.1 - ([6cddac5](https://github.com/seriaati/seria-library/commit/6cddac5c6bf0528d909f0b248d47107edb120748))
- **(deps)** update dependency ruff to v0.7.2 - ([3cfdc35](https://github.com/seriaati/seria-library/commit/3cfdc35957895c51630684f52086355bc749240a))
- **(deps)** update dependency ruff to v0.7.3 ([#75](https://github.com/seriaati/seria-library/issues/75)) - ([a18578f](https://github.com/seriaati/seria-library/commit/a18578f8f31d35547bb466c6ddd6dea5a68e10de))
- **(deps)** update dependency ruff to v0.7.4 ([#79](https://github.com/seriaati/seria-library/issues/79)) - ([9d04e4f](https://github.com/seriaati/seria-library/commit/9d04e4fb421198c8fa3bb3fdccaae8eb4e9e8660))
- **(deps)** update dependency ruff to ^0.8.0 ([#86](https://github.com/seriaati/seria-library/issues/86)) - ([9067f4c](https://github.com/seriaati/seria-library/commit/9067f4c3dbafed65033e4a971faebdf9501e3c7c))
- **(deps)** update dependency ruff to v0.8.1 ([#90](https://github.com/seriaati/seria-library/issues/90)) - ([19e5b3a](https://github.com/seriaati/seria-library/commit/19e5b3a22dce6f6071aa07592506575490963a12))
- **(deps)** update dependency ruff to v0.8.2 ([#92](https://github.com/seriaati/seria-library/issues/92)) - ([31b2870](https://github.com/seriaati/seria-library/commit/31b28703103cb0fad1499e41db9d5aab95c740e0))
- **(deps)** update dependency ruff to v0.8.3 ([#95](https://github.com/seriaati/seria-library/issues/95)) - ([e28e25c](https://github.com/seriaati/seria-library/commit/e28e25caac3a36a5010187eab0cb2036012d93ec))
- **(deps)** update dependency ruff to v0.8.4 ([#97](https://github.com/seriaati/seria-library/issues/97)) - ([ba1b33f](https://github.com/seriaati/seria-library/commit/ba1b33f38ea06aa9cc0ddf0714c481a92349cade))
- **(deps)** update dependency ruff to v0.8.5 ([#100](https://github.com/seriaati/seria-library/issues/100)) - ([ee4e985](https://github.com/seriaati/seria-library/commit/ee4e98596adf133f03f5b6f0e598c76d3478db15))
- **(deps)** update dependency ruff to v0.8.6 ([#101](https://github.com/seriaati/seria-library/issues/101)) - ([0505ec2](https://github.com/seriaati/seria-library/commit/0505ec2057252bdb76de4b73e742c11d68a8db73))
- **(deps)** update dependency ruff to ^0.9.0 ([#103](https://github.com/seriaati/seria-library/issues/103)) - ([c01b483](https://github.com/seriaati/seria-library/commit/c01b4834b3e8888a91d4c8c24118c310dde9e8a5))
- **(deps)** update dependency ruff to v0.9.1 ([#104](https://github.com/seriaati/seria-library/issues/104)) - ([a911d01](https://github.com/seriaati/seria-library/commit/a911d012076f1cbfd46cbb7e36f9d01e9e7b6578))
- **(deps)** update dependency ruff to v0.9.2 ([#105](https://github.com/seriaati/seria-library/issues/105)) - ([be17d95](https://github.com/seriaati/seria-library/commit/be17d95e099c7a4057ea111355eb1c476691ae59))
- **(deps)** update dependency ruff to v0.9.3 ([#108](https://github.com/seriaati/seria-library/issues/108)) - ([a4179f6](https://github.com/seriaati/seria-library/commit/a4179f6acc1761baf0c629591ab7ba7bacc6e204))
- **(deps)** update dependency ruff to v0.9.4 ([#109](https://github.com/seriaati/seria-library/issues/109)) - ([6973262](https://github.com/seriaati/seria-library/commit/6973262b0fae4f2068bc725484196f46d8fbfeee))
- **(deps)** update dependency ruff to v0.9.5 ([#111](https://github.com/seriaati/seria-library/issues/111)) - ([7009930](https://github.com/seriaati/seria-library/commit/7009930327db9baf54a011ceb6472f02972f9d2d))
- **(deps)** update dependency ruff to v0.9.6 ([#112](https://github.com/seriaati/seria-library/issues/112)) - ([633646a](https://github.com/seriaati/seria-library/commit/633646a847616d49edc6ff141d58ffe801292dca))
- **(deps)** update dependency ruff to v0.9.7 ([#114](https://github.com/seriaati/seria-library/issues/114)) - ([b0ed1fa](https://github.com/seriaati/seria-library/commit/b0ed1fa75cb83229b7b30c67c2defa2426232460))
- Remove .vscode/settings + add to gitignore - ([9b27b9f](https://github.com/seriaati/seria-library/commit/9b27b9ff9fe4af156edaf84b6963c2b7656ccb7c))
- Remove .pre-commit-config.yaml - ([ebdd8ff](https://github.com/seriaati/seria-library/commit/ebdd8ff71e50802caffd4e1b601fb199aaae7180))
- Migrate from poetry to uv - ([8727c21](https://github.com/seriaati/seria-library/commit/8727c218f565b09b685f02f876b952f3ff183579))
- Update renovate config - ([f0112dd](https://github.com/seriaati/seria-library/commit/f0112dd9988c1781bdabe7c2e0fc0105da0a9412))

